function [ GvsX ] = TotalG(G0A,G0B,varargin)
% TotalG(G0A,G0B,totmoles,expf);, last two arguments are optional
%   Calculates free energy of a mixture of A <-> B as a function of mole
%      fraction, plots several graphs showing patterns
% Jason Kahn U Maryland 2/25/2016  version 1.01
%   Input G0A = standard state molar free energy of A, G0B for B
%      totmoles = total # of moles. Default is 1. 
%   Set expf = 'y' if you want to call export_fig to output, default is no.
%   The molar free energy of each species is the standard state free
%      energy plus RT log X. Units of G are in RT for simplicity
%   X is the mole fraction of B, so 1-X is the mole fraction of A
%   Calculation assumes volume of 1 L, so 1 mole of A corresponds to 1 M A etc.
%   Returns a matrix of Total G versus X
%   Uses export_fig if and only if you want to make images.
%   Download export_fig from http://www.mathworks.com/matlabcentral/fileexchange/23629-exportfig
%   Calls mtit function to place overall title above plots
%   DL mtit from http://www.mathworks.com/matlabcentral/fileexchange/3218-mtit--a-pedestrian-major-title-creator
%   Also requires dsxy2figxy function, which makes arrows, from
%   https://www.mathworks.com/matlabcentral/fileexchange/30347-sigplot/content/sigplot/sigplot/BasicFunctions/dsxy2figxy.m
expf = 'n';
totmoles = 1;
if(nargin > 2)
    totmoles = varargin{1};
    if (nargin > 3)
        if (varargin{2} == 'y')
            expf = 'y';
        end
    end
end
smallinc=0.0005;
largeinc = 0.005;
changeover = 0.05;
X = [smallinc:smallinc:changeover changeover+largeinc:largeinc:(1-changeover) (1-changeover)+smallinc:smallinc:(1-smallinc)];
lenX = length(X);
midX = ceil(lenX/2);
% Molar free energies in units of RT
GA = G0A + log((1-X).*totmoles);
GB = G0B + log(X.*totmoles);
Keq = exp(-(G0B-G0A));
X_1M_B = 1/totmoles;
X_1M_A = 1 - X_1M_B;
% Total free energy of the mixture
GAtot = totmoles*(1-X).*GA;
GBtot = totmoles*(X).*GB;
% Calculate free energy change per mole converted
deltas = zeros(1,length(X)-1);
Y = zeros(1,length(X)-1);
for i = 1:(length(X)-1)
    deltas(i) = (-(GAtot(i)+GBtot(i))+(GAtot(i+1)+GBtot(i+1)))/(totmoles*(X(i+1)-X(i)));
    Y(i) = (X(i+1)+X(i))/2;
end
GvsX = [X' (GAtot+GBtot)'];
[minG,minX] = min(GAtot+GBtot);
disp(['Min G of ',num2str(minG),' at mole fraction ',num2str(X(minX))])
disp(['Keq calc as ',num2str(X(minX)/(1-X(minX))),' from X at minG ',num2str(X(minX))])
%
zf=figure('Position',[100 100 800 600]);
set(zf,'Color',[0.95,0.95,0.95])

%  subplot('Position',[left bottom width height])
h2 = subplot(2,2,1);
posi = get(h2,'Position');
posi(2) = posi(2) - 0.04;
set(h2,'Position',posi)
plot(X,GAtot+GBtot,'LineWidth',2)
v = axis;
line([X(minX) X(minX)],[v(3) v(4)],'Color',[.7 .5 0],'LineWidth',1)
line([0,1],[minG,minG],'Color','r','LineWidth',1)
title('Total free energy of A + B Mixture','FontSize',14)
text(v(1)+0.03*v(2),v(3)+0.85*(v(4)-v(3)),['Min G of ',num2str(minG),' at mole fraction ',num2str(X(minX))],...
    'FontSize',14,'Color',[.7 .5 0],'BackgroundColor','w')
text(v(1)+0.15*v(2),v(3)+0.75*(v(4)-v(3)),['Keq = ',num2str(Keq)],...
    'FontSize',14,'Color',[.7 .5 0],'BackgroundColor','w')
ylabel('G (units of RT)','FontSize',14)
p = mtit(zf,'Free Energy of A+B Mixture vs. Mole Fraction of B','xoff',0.65,'yoff',0.12,...
    'FontSize',16);
set(p.th,'Color','red','FontWeight','bold');
set(gca,'XTick',0:0.1:1)

%
h1 = subplot(2,2,2);
posi = get(h1,'Position');   % left bottom width height
posi(2) = posi(2) - 0.04;
set(h1,'Position',posi)
plot(X,GA,X,GB,'LineWidth',2)
set(gca,'XTick',0:0.1:1)
title('Molar free energies of A and B','FontSize',14)
ylabel('G (units of RT), per mole','FontSize',12)
line([0,1],[minG,minG]/totmoles,'Color','r','LineWidth',1)
line([0,1],[G0A,G0A],'Color','k','LineWidth',1)
line([0,1],[G0B,G0B],'Color','k','LineWidth',1)
v = axis ; % v = [xmin xmax ymin ymax]
line([X(minX) X(minX)],[v(3) v(4)],'Color',[.7 .5 0],'LineWidth',1)
text(v(1)+0.03*v(2),v(3)+0.15*(v(4)-v(3)),{['Molar G0A = ',num2str(G0A)],['Molar G0B = ',num2str(G0B)]},...
    'FontSize',14,'BackgroundColor','w')
if (G0A == G0B)
    text(0.25,v(4)-0.08*(v(4)-v(3)),'Delta G0 = 0',...
    'FontSize',14,'Color','m','BackgroundColor','w')
else
    %rectangle annotation
    if (G0A < G0B)
        ybox = ((G0A - v(3))/(v(4) - v(3))*posi(4) + posi(2) - 0.09*(posi(4)));
annotation('rectangle',[((0.13 - v(1))/(v(2)-v(1))*posi(3) + posi(1)) , ybox, 0.22*posi(3),0.08*posi(4)],...
    'Color','m','FaceColor','w','EdgeColor','m')
    else
        ybox = ((G0A - v(3))/(v(4) - v(3))*posi(4) + posi(2) + 0.01*(posi(4)));
annotation('rectangle',[((0.13 - v(1))/(v(2)-v(1))*posi(3) + posi(1)) , ybox, 0.22*posi(3),0.08*posi(4)],...
    'Color','m','FaceColor','w','EdgeColor','m')
    end
annotation('arrow',[((0.25 - v(1))/(v(2)-v(1))*posi(3) + posi(1)) ...
    ((0.25 - v(1))/(v(2)-v(1))*posi(3) + posi(1))],...
     [((G0A - v(3))/(v(4) - v(3))*posi(4) + posi(2)) ...
         ((G0B - v(3))/(v(4) - v(3))*posi(4) + posi(2))],...
     'Color','k','LineWidth',1.5)

annotation('textarrow',[((0.25 - v(1))/(v(2)-v(1))*posi(3) + posi(1)) ...
    ((0.25 - v(1))/(v(2)-v(1))*posi(3) + posi(1))],...
     [((G0A - v(3))/(v(4) - v(3))*posi(4) + posi(2)) ...
         ((G0B - v(3))/(v(4) - v(3))*posi(4) + posi(2))],...
     'Color','k','LineWidth',1.5,'String','DeltaG0','FontSize',14)

% [(X_1M_A - v(1))/(v(2)-v(1))*posi(3) + posi(1),...
%    (G0A - v(3))/(v(4) - v(3))*posi(4) + posi(3),...
%    posi(3)*0.05 , posi(4)*0.05]
% annotation('rectangle',posi,'Color','cyan')
if(totmoles >= 1)
colm = get(gca,'ColorOrder');
 annotation('ellipse',[(X_1M_A - v(1))/(v(2)-v(1))*posi(3) + posi(1) - posi(3)*0.02,...
     (G0A - v(3))/(v(4) - v(3))*posi(4) + posi(2) - posi(4)*0.02,...
     posi(3)*0.04 , posi(4)*0.04],'Color',colm(1,:),'LineWidth',2)
 annotation('ellipse',[(X_1M_B - v(1))/(v(2)-v(1))*posi(3) + posi(1) - posi(3)*0.02,...
     (G0B - v(3))/(v(4) - v(3))*posi(4) + posi(2) - posi(4)*0.02,...
     posi(3)*0.04 , posi(4)*0.04],'Color',colm(2,:),'LineWidth',2)
end
end
legend('Molar GA','Molar GB','Location','SouthEast')

[arrowx,arrowy] = dsxy2figxy(gca, [0.5 0.5], [GA(midX) GB(midX)]);
har = annotation('textarrow',arrowx,arrowy,'Color','k','LineWidth',1.5,'String','DeltaG0','FontSize',14);
set(har,'Color','m')

%
h = subplot(2,2,4);
get(h,'Position');
plot(X,GAtot,X,GBtot,'LineWidth',2)
set(gca,'XTick',0:0.1:1)
v = axis;
title('Total free energies of A and B','FontSize',14)
xlabel('Mole Fraction of B','FontSize',14)
ylabel('G (units of RT)','FontSize',14)
text(v(1)+0.3*(v(2)-v(1)),v(3)+0.08*(v(4)-v(3)),['Total moles = ',num2str(totmoles)],...
    'FontSize',14,'BackgroundColor','w')
line([0 1],[0 0],'Color','k','LineWidth',1)
legend('Total GA','Total GB','Location','East')

%
h = subplot(2,2,3);
get(h,'Position');
plot(Y,deltas,'LineWidth',2)
v = axis;
set(gca,'XTick',0:0.1:1)
line([0,1],[0,0],'Color','r','LineWidth',1)
line([0.5,0.5],[v(3) v(4)],'Color','m','LineWidth',1)
text(0.25,v(3)+0.08*(v(4)-v(3)),'Delta G at Q = 1 is DeltaG0',...
    'FontSize',14,'Color','m','BackgroundColor','w')
title('Delta G per mole of A converted to B','FontSize',14)
xlabel('Mole Fraction of B','FontSize',14)
ylabel('DeltaG (units of RT)','FontSize',14)
line([X(minX) X(minX)],[v(3) v(4)],'Color',[.7 .5 0],'LineWidth',1)
text(max(.05,min(X(minX),0.4)),0.85*(v(4)-v(3))+v(3),'Delta G at min G is 0',...
    'FontSize',14,'Color',[.7 .5 0],'BackgroundColor','w')

%
%shg
if (expf == 'y')
export_fig(sprintf('AplusB_G_%.2g_%.2g_%.2g',G0A,G0B,totmoles),'-m2','-painters')
filename = sprintf('AplusB_G_%.2g_%.2g_%.2g',G0A,G0B,totmoles);
disp (['Graphs saved using export_fig as ', filename ])
end
end

